lmi-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[lmi-commits] [lmi] master bbd58e70: Correct a mistaken condition


From: Greg Chicares
Subject: [lmi-commits] [lmi] master bbd58e70: Correct a mistaken condition
Date: Fri, 3 Mar 2023 16:00:46 -0500 (EST)

branch: master
commit bbd58e70b9898e7fe64bc91f42805080be63fd48
Author: Gregory W. Chicares <gchicares@sbcglobal.net>
Commit: Gregory W. Chicares <gchicares@sbcglobal.net>

    Correct a mistaken condition
    
    See:
      https://lists.nongnu.org/archive/html/lmi/2023-01/msg00012.html
    which discussed adding a test for TTY existence when the apparent
    problem is that no X server is running.
---
 nychthemeral_test.sh | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/nychthemeral_test.sh b/nychthemeral_test.sh
index 3cfd2c81..c3dc73a7 100755
--- a/nychthemeral_test.sh
+++ b/nychthemeral_test.sh
@@ -224,13 +224,13 @@ schemata_clutter='
 /^  Done\.$/d
 '
 
 # When /dev/tty doesn't exist, 'wine' issues these extra diagnostics.
 #
 # Escape a literal dollar sign as '[$]' rather than '\$'. The latter
 # is less weird, but 'shellcheck' thinks '\$VARIABLE' calls for an
 # expansion.
 
-absent_tty_clutter='
+no_X_server_clutter='
 /^[[:xdigit:]]*:err:winediag:nodrv_CreateWindow Application tried to create a 
window, but no driver could be loaded\.$/d
 /^[[:xdigit:]]*:err:winediag:nodrv_CreateWindow L"The explorer process failed 
to start."$/d
 /^[[:xdigit:]]*:err:winediag:nodrv_CreateWindow Make sure that your X server 
is running and that [$]DISPLAY is set correctly\.$/d
@@ -279,7 +279,7 @@ nychthemeral_clutter='
 /^$/d
 '
 
-if ! tty -s; then 
nychthemeral_clutter="${absent_tty_clutter}${nychthemeral_clutter}"; fi
+if ! xdpyinfo >/dev/null 2>&1; then 
nychthemeral_clutter="${no_X_server_clutter}${nychthemeral_clutter}"; fi
 
 # Install a bland 'configurable_settings.xml' for all architectures.
@@ -224,13 +224,13 @@ schemata_clutter='
 '
 
-# When /dev/tty doesn't exist, 'wine' issues these extra diagnostics.
+# When no X server is running, 'wine' issues these extra diagnostics.
 #
 # Escape a literal dollar sign as '[$]' rather than '\$'. The latter
 # This overwrites any existing file, but developers probably won't



reply via email to

[Prev in Thread] Current Thread [Next in Thread]